@@ -45,10 +45,11 @@ class ClickHouse:
         if key not in _df.columns:
             raise Exception(f"key `{key}` not found in columns, columns are {_df.columns}")
         status, e = create_table(self._client, _df, tableName, key)
-        if status == False and e.code != 57:
-            raise e
-        elif e.code == 57:
-            print(f"table {tableName} already exists!")
+        if status == False:
+            if e.code == 57:
+                print(f"table {tableName} already exists!")
+            else:
+                raise e
         return tableName
     
     def write(self, ddf=None, df=None, tableName=None, key=None):
