@@ -37,7 +37,7 @@ class DataNode(DatasetManager):
         if _res.status_code != 201:
             raise Exception(f"can not create directory in discovery {_res.json()}")
         meta = _res.json()
-        _df_ddf = ddf if ddf != None else df
+        _df_ddf = ddf if type(ddf) == dd.DataFrame else df
         _df_ddf.to_parquet(f"s3://{bucket_name}/{meta['key']}",
             storage_options=self._storage_options,
             **kwargs
