@@ -3,7 +3,7 @@ import requests
 from tqdm.auto import tqdm
 from tqdm.utils import CallbackIOWrapper
 
-from .base import discovery_api, Base
+from .base import Base
 class DatasetManager(Base):
 
     def upload_file(self, directory_id=None, file_path=None, description=""):
@@ -13,17 +13,18 @@ class DatasetManager(Base):
             raise Exception(f"file {os.path.abspath(file_path)} not found")
         if directory_id == None:
              raise Exception("please input directory, like `directory=<id>`")
-        _res = requests.get(f"{discovery_api}/directory/{directory_id}",  headers=self._jwt_header)
+        _res = requests.get(f"{self._discovery_api}/directory/{directory_id}",  headers=self._jwt_header)
         if _res.status_code == 404:
             raise Exception(f"directory {directory_id} not found or your dose not has permission to access directory")
         f_name = os.path.basename(file_path)
-        _res = requests.post(f"{discovery_api}/file/", headers=self._jwt_header,
+        replace = self._check_fileExists(directory_id, f_name)
+        _res = requests.post(f"{self._discovery_api}/file/", headers=self._jwt_header,
                              data={
                                  'name': f_name,
                                  'description': f_name,
                                  'directory': int(directory_id),
                                  'size': os.path.getsize(file_path),
-                                 'is_use': True
+                                 'replace': replace
                              }
                 )
         if not _res.status_code in [200, 201]:
@@ -32,6 +33,8 @@ class DatasetManager(Base):
                 txt = _res.json()
             raise Exception(f"{_res.status_code}, {txt}")
         data = _res.json()
+        if self._internal:
+            data['url'] = self._replace_minio_api(data['url'])
         file_size = os.stat(file_path).st_size
         with open(file_path, 'rb') as f:
             with tqdm(total=file_size, unit="B", unit_scale=True, unit_divisor=1024) as t:
@@ -50,15 +53,19 @@ class DatasetManager(Base):
     def download_file(self, file_id=None, download_path=None):
         if file_id == None:
              raise Exception("please input file_id")
-        _res = requests.get(f"{discovery_api}/file/{file_id}/",  headers=self._jwt_header)
+        _res = requests.get(f"{self._discovery_api}/file/{file_id}/",  headers=self._jwt_header)
         if _res.status_code != 200:
             raise Exception(f"File response code {_res}")
         meta = _res.json()
-        _res = requests.get(f"{discovery_api}/file/{file_id}/download/",  headers=self._jwt_header)
+        _res = requests.get(f"{self._discovery_api}/file/{file_id}/download/",  headers=self._jwt_header)
         if _res.status_code != 200:
             raise Exception("some thing wrong in datastore")
-        
-        _res = requests.get(_res.json()['url'])
+            
+        _url = _res.json()['url']
+        if self._internal:
+            _url = self._replace_minio_api(_url)
+            
+        _res = requests.get(_url)
         f_path = os.path.join(self._tmp_path, meta['name'])
         if download_path != None:
             if (not os.path.exists(download_path)) or (not os.path.isdir(download_path)):
